macro_rules! function_name {
() => { ... };
}Expand description
Expands to the unqualified name of the enclosing function/method as a &'static str.
macro_rules! function_name {
() => { ... };
}Expands to the unqualified name of the enclosing function/method as a &'static str.