macro_rules! serializable_retry {
($self:expr, $f:expr) => { ... };
}Expand description
Calls SerializableRetry::serializable_retry with op set to the unqualified name of the
enclosing function via function_name!.
macro_rules! serializable_retry {
($self:expr, $f:expr) => { ... };
}Calls SerializableRetry::serializable_retry with op set to the unqualified name of the
enclosing function via function_name!.